Crate breb

Crate breb 

blog/reblog is oriented around the Blog: a collection of Serves with some sitewide metadata. each Serve knows how to render the files in it, and the Blog maps the actual incoming requests to them. the responses are in the form of Servables, which map cleanly to http responses.

Modules

docs
miscellaneous documentation, exposed via crate docs for offline friendliness
quick
all the imports you usually need. use breb::quick::* for best results.
raw
defining the structure of a blog in a direct, very predictable way
serve
the part of the blog that can actually serve files

Structs

Blog
a blog that’s fully ready to serve files
LiveServer
serve a raw::Config, fresh from the disk
Metadata
metadata about the blog, as supplied by serves
Mime
the mime type of a file (i.e. at a Url)
Post
metadata about a syndicated blogpost.
Servable
information about a file that this blog can render.