Mime

Struct Mime 

pub struct Mime(pub Cow<'static, str>);
the mime type of a file (i.e. at a Url)

Tuple Fields

0: Cow<'static, str>

Implementations

Source

impl Mime

pub const fn of(s: &'static str) -> Self

arbitrary mime type from a fixed string

this exists just to give the const-initialization a shorthand; if you need to create a Mime at runtime, you can use its From<impl Into<Cow<'static, str>>> impl.

Source

impl Mime

pub const HTML: Self

pub const CSS: Self

pub const JAVASCRIPT: Self

pub const XML: Self

application/xml: extensible markup language

pub const RSS: Self

application/rss+xml: unofficially standardized ‘real simple syndication’

pub const ATOM: Self

application/atom+xml: atom syndication format

pub const JSON: Self

application/json: javascript object notation

pub const PNG: Self

pub const JPEG: Self

pub const GIF: Self

pub const SVG: Self

pub const ICO: Self

image/vnd.microsoft.icon: corporate icon format

pub const WOFF: Self

pub const WOFF2: Self

pub const TTF: Self

font/ttf: corporate font format

pub const OTF: Self

font/otf: corporate font format

pub const BYTES: Self

application/octet-stream: Arbitrary bytes, and the default for unknown data

pub fn from_ext(ext: &str) -> Option<Self>

guess the mime type based on a file extension

this is a generally unreliable way to do things. ideally, we would be introspecting the first few bytes of the file, and making an educated decision based on the magic bytes. but that’s far more complex than this approach, and browsers will generally adapt anyway, so w/e.