Modules
- docs
- miscellaneous documentation, exposed via crate docs for offline friendliness
- quick
- all the imports you usually need.
use breb::quick::*for best results. - raw
- defining the structure of a blog in a direct, very predictable way
- serve
- the part of the blog that can actually serve files
Structs
- Blog
- a blog that’s fully ready to serve files
- Live
Server - serve a
raw::Config, fresh from the disk - Metadata
- metadata about the blog, as supplied by serves
- Mime
- the mime type of a file (i.e. at a
Url) - Post
- metadata about a syndicated blogpost.
- Servable
- information about a file that this blog can render.