Modules
- quick
- all the imports you usually need.
use breb::quick::*for best results. - serve
- the part of the blog that can actually serve files
Structs
- Author
- info for the atom feed about the blog’s author(s).
- Blog
- a blog that’s fully ready to serve files
- Config
- defines the structure of a blog
- Live
Server - serve a
Config, fresh from the disk - Metadata
- metadata about the blog, as supplied by serves
- Mime
- the mime type of a file (i.e. at a
Url) - Post
- metadata about a syndicated blogpost.
- Servable
- information about a file that this blog can render.
Enums
- Template
Src - tells the blog where to load its templates when it loads