pub fn run(cfg: Config)Expand description
a wrapper function to do the boilerplate of a basic, statically defined blog:
- pull the in and out directories out of the args, including a little help message
- read the blog from the input and write it to the output
usage is simple; build your Config and pass it in.
the cli is, admittedly, a little more complex:
-h/--help/help: print some help textrun <in> <out>: run the blog generation once, writing it to<out>serve <in>: serve the blog directly off disk